@@ -1,6 +1,6 @@
 package ETL::Yertl::Command::ysql;
 # ABSTRACT: Read and write documents with a SQL database
-$ETL::Yertl::Command::ysql::VERSION = '0.024';
+$ETL::Yertl::Command::ysql::VERSION = '0.025';
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray :config pass_through );
 use ETL::Yertl::Format::yaml;
@@ -125,12 +125,19 @@ sub main {
             die "Must specify a database!\n";
         }
 
-        my @dbi_args = $opt{dsn} ? ( $opt{dsn} ) : dbi_args( $db_key );
+        my @dbi_args = $opt{dsn} ? ( $opt{dsn}, undef, undef ) : dbi_args( $db_key );
         if ( !@dbi_args ) {
             die "Unknown database '$db_key'\n";
         }
 
         my $dbh = DBI->connect( @dbi_args, { PrintError => 0 } );
+        if ( !$dbh ) {
+            no warnings 'once';
+            die sprintf qq{Could not connect to database "\%s"\%s: \%s\n},
+                $dbi_args[0],
+                $dbi_args[1] ? qq{ (user: "$dbi_args[1]")} : '',
+                $DBI::errstr;
+        }
 
         my $query = shift @args;
         if ( $db_key ) {
@@ -242,7 +249,7 @@ ETL::Yertl::Command::ysql - Read and write documents with a SQL database
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 AUTHOR
 
